@@ -2,7 +2,7 @@ module OmniAuth
   class Builder < ::Rack::Builder
     def initialize(app, &block)
       @options = nil
-      if rack14?
+      if rack14? || rack2?
         super
       else
         @app = app
@@ -12,7 +12,11 @@ module OmniAuth
     end
 
     def rack14?
-      Rack.release.split('.')[1].to_i >= 4
+      Rack.release.start_with?('1.') && (Rack.release.split('.')[1].to_i >= 4)
+    end
+
+    def rack2?
+      Rack.release.start_with? '2.'
     end
 
     def on_failure(&block)
