@@ -6,7 +6,7 @@ module OmniAuth
   # wrangle multiple providers. Each strategy provided by
   # OmniAuth includes this mixin to gain the default functionality
   # necessary to be compatible with the OmniAuth library.
-  module Strategy
+  module Strategy # rubocop:disable ModuleLength
     def self.included(base)
       OmniAuth.strategies << base
 
@@ -169,7 +169,7 @@ module OmniAuth
     # the request path is recognized.
     #
     # @param env [Hash] The Rack environment.
-    def call!(env) # rubocop:disable CyclomaticComplexity
+    def call!(env) # rubocop:disable CyclomaticComplexity, PerceivedComplexity
       unless env['rack.session']
         error = OmniAuth::NoSessionError.new('You must provide a session to use OmniAuth.')
         fail(error)
@@ -194,7 +194,7 @@ module OmniAuth
     end
 
     # Performs the steps necessary to run the request phase of a strategy.
-    def request_call # rubocop:disable CyclomaticComplexity, MethodLength
+    def request_call # rubocop:disable CyclomaticComplexity, MethodLength, PerceivedComplexity
       setup_phase
       log :info, 'Request phase initiated.'
       # store query params from the request url, extracted in the callback_phase
@@ -278,14 +278,14 @@ module OmniAuth
 
     def mock_callback_call
       setup_phase
+      @env['omniauth.origin'] = session.delete('omniauth.origin')
+      @env['omniauth.origin'] = nil if env['omniauth.origin'] == ''
       mocked_auth = OmniAuth.mock_auth_for(name.to_s)
       if mocked_auth.is_a?(Symbol)
         fail!(mocked_auth)
       else
         @env['omniauth.auth'] = mocked_auth
         @env['omniauth.params'] = session.delete('omniauth.params') || {}
-        @env['omniauth.origin'] = session.delete('omniauth.origin')
-        @env['omniauth.origin'] = nil if env['omniauth.origin'] == ''
         OmniAuth.config.before_callback_phase.call(@env) if OmniAuth.config.before_callback_phase
         call_app!
       end
@@ -377,23 +377,27 @@ module OmniAuth
     end
 
     def request_path
-      options[:request_path].is_a?(String) ? options[:request_path] : "#{path_prefix}/#{name}"
+      @request_path ||= options[:request_path].is_a?(String) ? options[:request_path] : "#{path_prefix}/#{name}"
     end
 
     def callback_path
-      path = options[:callback_path] if options[:callback_path].is_a?(String)
-      path ||= current_path if options[:callback_path].respond_to?(:call) && options[:callback_path].call(env)
-      path ||= custom_path(:request_path)
-      path ||= "#{path_prefix}/#{name}/callback"
-      path
+      @callback_path ||= begin
+        path = options[:callback_path] if options[:callback_path].is_a?(String)
+        path ||= current_path if options[:callback_path].respond_to?(:call) && options[:callback_path].call(env)
+        path ||= custom_path(:request_path)
+        path ||= "#{path_prefix}/#{name}/callback"
+        path
+      end
     end
 
     def setup_path
       options[:setup_path] || "#{path_prefix}/#{name}/setup"
     end
 
+    CURRENT_PATH_REGEX = %r{/$}
+    EMPTY_STRING       = ''.freeze
     def current_path
-      request.path_info.downcase.sub(/\/$/, '')
+      @current_path ||= request.path_info.downcase.sub(CURRENT_PATH_REGEX, EMPTY_STRING)
     end
 
     def query_string
@@ -475,6 +479,12 @@ module OmniAuth
       OmniAuth.config.on_failure.call(env)
     end
 
+    def dup
+      super.tap do
+        @options = @options.dup
+      end
+    end
+
     class Options < Hashie::Mash; end
 
   protected
@@ -488,10 +498,10 @@ module OmniAuth
 
     def ssl?
       request.env['HTTPS'] == 'on' ||
-      request.env['HTTP_X_FORWARDED_SSL'] == 'on' ||
-      request.env['HTTP_X_FORWARDED_SCHEME'] == 'https' ||
-      (request.env['HTTP_X_FORWARDED_PROTO'] && request.env['HTTP_X_FORWARDED_PROTO'].split(',')[0] == 'https') ||
-      request.env['rack.url_scheme'] == 'https'
+        request.env['HTTP_X_FORWARDED_SSL'] == 'on' ||
+        request.env['HTTP_X_FORWARDED_SCHEME'] == 'https' ||
+        (request.env['HTTP_X_FORWARDED_PROTO'] && request.env['HTTP_X_FORWARDED_PROTO'].split(',')[0] == 'https') ||
+        request.env['rack.url_scheme'] == 'https'
     end
   end
 end
