@@ -1,13 +1,14 @@
-require 'simplecov'
-require 'coveralls'
+if RUBY_VERSION >= '1.9'
+  require 'simplecov'
+  require 'coveralls'
 
-SimpleCov.formatter = SimpleCov::Formatter::MultiFormatter[
-  SimpleCov::Formatter::HTMLFormatter,
-  Coveralls::SimpleCov::Formatter
-]
-SimpleCov.start do
-  add_filter '/spec/'
-  minimum_coverage(93.05)
+  SimpleCov.formatters = [SimpleCov::Formatter::HTMLFormatter, Coveralls::SimpleCov::Formatter]
+
+  SimpleCov.start do
+    add_filter '/spec/'
+    add_filter '/vendor/'
+    minimum_coverage(92.93)
+  end
 end
 
 require 'rspec'
@@ -31,7 +32,7 @@ class ExampleStrategy
   option :name, 'test'
 
   def call(env)
-    self.call!(env)
+    options[:dup] ? super : self.call!(env)
   end
 
   def initialize(*args, &block)
@@ -40,6 +41,7 @@ class ExampleStrategy
   end
 
   def request_phase
+    options[:mutate_on_request].call(options) if options[:mutate_on_request]
     @fail = fail!(options[:failure]) if options[:failure]
     @last_env = env
     return @fail if @fail
@@ -47,6 +49,7 @@ class ExampleStrategy
   end
 
   def callback_phase
+    options[:mutate_on_callback].call(options) if options[:mutate_on_callback]
     @fail = fail!(options[:failure]) if options[:failure]
     @last_env = env
     return @fail if @fail
