@@ -5,7 +5,7 @@ describe OmniAuth::Strategies::Developer do
     Rack::Builder.new do |b|
       b.use Rack::Session::Cookie, :secret => 'abc123'
       b.use OmniAuth::Strategies::Developer
-      b.run lambda { |env| [200, {}, ['Not Found']] }
+      b.run lambda { |_env| [200, {}, ['Not Found']] }
     end.to_app
   end
 
@@ -52,7 +52,7 @@ describe OmniAuth::Strategies::Developer do
         Rack::Builder.new do |b|
           b.use Rack::Session::Cookie, :secret => 'abc123'
           b.use OmniAuth::Strategies::Developer, :fields => [:first_name, :last_name], :uid_field => :last_name
-          b.run lambda { |env| [200, {}, ['Not Found']] }
+          b.run lambda { |_env| [200, {}, ['Not Found']] }
         end.to_app
       end
 
