@@ -337,7 +337,6 @@ describe OmniAuth::Strategy do
           expect { strategy.call(make_env('/auth/test/callback', env)) }.to raise_error('Callback Phase')
           expect(strategy.last_env['omniauth.origin']).to eq('http://example.com/sub_uri/origin')
         end
-
       end
     end
 
@@ -424,9 +423,7 @@ describe OmniAuth::Strategy do
       end
 
       it 'correctly reports the callback path when the custom callback path evaluator is truthy' do
-        strategy_instance = ExampleStrategy.new(app,
-                                                :callback_path => lambda { |env| env['PATH_INFO'] == '/auth/bish/bosh/callback' }
-        )
+        strategy_instance = ExampleStrategy.new(app, :callback_path => lambda { |env| env['PATH_INFO'] == '/auth/bish/bosh/callback' })
 
         expect { strategy_instance.call(make_env('/auth/bish/bosh/callback')) }.to raise_error('Callback Phase')
         expect(strategy_instance.callback_path).to eq('/auth/bish/bosh/callback')
@@ -546,6 +543,52 @@ describe OmniAuth::Strategy do
       end
     end
 
+    context 'options mutation' do
+      before do
+        @options = {:dup => true}
+      end
+
+      context 'in request phase' do
+        it 'does not affect original options' do
+          @options.merge!(
+            :test_option => true,
+            :mutate_on_request => proc { |options| options.delete(:test_option) }
+          )
+          expect { strategy.call(make_env) }.to raise_error('Request Phase')
+          expect(strategy.options).to have_key(:test_option)
+        end
+
+        it 'does not affect deep options' do
+          @options.merge!(
+            :deep_option => {:test_option => true},
+            :mutate_on_request => proc { |options| options[:deep_option].delete(:test_option) }
+          )
+          expect { strategy.call(make_env) }.to raise_error('Request Phase')
+          expect(strategy.options[:deep_option]).to have_key(:test_option)
+        end
+      end
+
+      context 'in callback phase' do
+        it 'does not affect original options' do
+          @options.merge!(
+            :test_option => true,
+            :mutate_on_callback => proc { |options| options.delete(:test_option) }
+          )
+          expect { strategy.call(make_env('/auth/test/callback', 'REQUEST_METHOD' => 'POST')) }.to raise_error('Callback Phase')
+          expect(strategy.options).to have_key(:test_option)
+        end
+
+        it 'does not affect deep options' do
+          @options.merge!(
+            :deep_option => {:test_option => true},
+            :mutate_on_callback => proc { |options| options[:deep_option].delete(:test_option) }
+          )
+          expect { strategy.call(make_env('/auth/test/callback', 'REQUEST_METHOD' => 'POST')) }.to raise_error('Callback Phase')
+          expect(strategy.options[:deep_option]).to have_key(:test_option)
+        end
+      end
+    end
+
     context 'test mode' do
       let(:app) do
         # In test mode, the underlying app shouldn't be called on request phase.
